@@ -51,6 +51,8 @@ static const char sccsid[] = "@(#)bug.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "automata.h"
 
+#ifdef MODE_bug
+
 ModeSpecOpt bug_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -576,27 +578,27 @@ flush_buglist(bugfarmstruct * bp)
 }
 
 static int
-dirbug(bugstruct * info, int neighbors)
+dirbug(bugstruct * info, int local_neighbors)
 {
 	double      sum = 0.0, prob;
 	int         i;
 
 	prob = (double) LRAND() / MAXRAND;
-	for (i = 0; i < neighbors; i++) {
+	for (i = 0; i < local_neighbors; i++) {
 		sum += info->gene_prob[i];
 		if (prob < sum)
 			return i;
 	}
-	return neighbors - 1;	/* Could miss due to rounding */
+	return local_neighbors - 1;	/* Could miss due to rounding */
 }
 
 static void
-mutatebug(bugstruct * info, int neighbors)
+mutatebug(bugstruct * info, int local_neighbors)
 {
 	double      sum = 0.0;
 	int         gene;
 
-	gene = NRAND(neighbors);
+	gene = NRAND(local_neighbors);
 	if (LRAND() & 1) {
 		if (info->gene[gene] == MAXGENE)
 			return;
@@ -606,9 +608,9 @@ mutatebug(bugstruct * info, int neighbors)
 			return;
 		info->gene[gene]--;
 	}
-	for (gene = 0; gene < neighbors; gene++)
+	for (gene = 0; gene < local_neighbors; gene++)
 		sum += genexp[info->gene[gene] + MAXGENE];
-	for (gene = 0; gene < neighbors; gene++)
+	for (gene = 0; gene < local_neighbors; gene++)
 		info->gene_prob[gene] = genexp[info->gene[gene] + MAXGENE] / sum;
 }
 
@@ -948,3 +950,5 @@ refresh_bug(ModeInfo * mi)
 		bp->redrawpos = 0;
 	}
 }
+
+#endif /* MODE_bug */
