@@ -56,6 +56,8 @@ static const char sccsid[] = "@(#)deco.c 4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
 
+#ifdef MODE_deco
+
 ModeSpecOpt deco_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -180,3 +182,5 @@ release_deco(ModeInfo * mi)
 		decos = NULL;
 	}
 }
+
+#endif /* MODE_deco */
