@@ -85,6 +85,8 @@ static const char sccsid[] = "@(#)flag.c	4.07 97/11/24 xlockmore";
 #include "iostuff.h"
 #endif
 
+#ifdef MODE_flag
+
 #define DEF_INVERT  "False"
 
 static Bool invert;
@@ -579,3 +581,5 @@ refresh_flag(ModeInfo * mi)
 
 	MI_CLEARWINDOWCOLORMAP(mi, fp->backGC, fp->black);
 }
+
+#endif /* MODE_flag */
