@@ -28,7 +28,7 @@ static const char sccsid[] = "@(#)helix.c	4.07 97/11/24 xlockmore";
  * 08-Aug-95: speed up thanks to Heath A. Kehoe <hakehoe@icaen.uiowa.edu>
  * 17-Jun-95: removed sleep statements
  * 2-Sep-93: xlock version David Bagley <bagleyd@bigfoot.com>
- * 1992:     xscreensaver version Jamie Zawinski <jwz@netscape.com>
+ * 1992:     xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
@@ -59,6 +59,8 @@ static const char sccsid[] = "@(#)helix.c	4.07 97/11/24 xlockmore";
 
 #endif /* STANDALONE */
 
+#ifdef MODE_helix
+
 #define DEF_ELLIPSE "False"
 
 static Bool ellipse;
@@ -241,7 +243,7 @@ random_helix(ModeInfo * mi)
 		hp->d_angle = NRAND(ANGLES);
 
 #define random_factor()				\
-  (((NRAND(7)) ? ((LRAND() & 1) + 1) : 3)	* (((LRAND() & 1) * 2) - 1))
+  (int) (((NRAND(7)) ? ((LRAND() & 1) + 1) : 3)	* (((LRAND() & 1) * 2) - 1))
 
 	while (gcd(gcd(gcd(hp->factor1, hp->factor2), hp->factor3), hp->factor4)
 	       != 1) {
@@ -329,6 +331,8 @@ draw_helix(ModeInfo * mi)
 {
 	helixstruct *hp = &helixes[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (++hp->time > MI_CYCLES(mi))
 		init_helix(mi);
 	else
@@ -365,3 +369,5 @@ refresh_helix(ModeInfo * mi)
 		hp->painted = False;
 	}
 }
+
+#endif /* MODE_helix */
