@@ -6,7 +6,6 @@ static const char sccsid[] = "@(#)ico.c	4.07 97/11/24 xlockmore";
 
 #endif
 
-
 /*-
  * Copyright (c) 1987  X Consortium
  *
@@ -106,6 +105,8 @@ SOFTWARE.
 
 #endif /* STANDALONE */
 
+#ifdef MODE_ico
+
 #define DEF_FACES "False"
 #define DEF_EDGES "True"	/* Wire frame edges, set true if faces false. */
 
@@ -923,3 +924,5 @@ change_ico(ModeInfo * mi)
 
 	initPoly(mi, ip->poly, ip->polyW, ip->polyH);
 }
+
+#endif /* MODE_ico */
