@@ -46,6 +46,8 @@ static const char sccsid[] = "@(#)image.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "iostuff.h"
 
+#ifdef MODE_image
+
 ModeSpecOpt image_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -246,3 +248,5 @@ release_image(ModeInfo * mi)
 		ims = NULL;
 	}
 }
+
+#endif /* MODE_image */
