@@ -72,6 +72,8 @@ static const char sccsid[] = "@(#)star.c	4.07 97/11/24 xlockmore";
 
 #endif /* STANDALONE */
 
+#ifdef MODE_star
+
 #define DEF_TREK  "50"
 #define DEF_ROCK  "False"
 #define DEF_STRAIGHT  "False"
@@ -732,3 +734,5 @@ refresh_star(ModeInfo * mi)
 		MI_CLEARWINDOW(mi);
 	}
 }
+
+#endif /* MODE_star */
