@@ -50,6 +50,8 @@ static const char sccsid[] = "@(#)swirl.c	4.07 97/11/24 xlockmore";
 #include "color.h"
 #endif /* !STANDALONE */
 
+#ifdef MODE_swirl
+
 ModeSpecOpt swirl_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -1474,3 +1476,5 @@ refresh_swirl(ModeInfo * mi)
 		swirl->drawing = False;
 	}
 }
+
+#endif /* MODE_swirl */
